/**
  ******************************************************************************
  * @file stm8_type.h
  * @brief This file contains all common data types.
  * @author STMicroelectronics
  * @version
  * @date 04-OCT-2007
  ******************************************************************************
  *
  * THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2007 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM8_TYPE_H
#define __STM8_TYPE_H

/* Includes ------------------------------------------------------------------*/
/* Exported types ------------------------------------------------------------*/
typedef signed long  s32;
typedef signed short s16;
typedef signed char  s8;

typedef signed long  const sc32;  /* Read Only */
typedef signed short const sc16;  /* Read Only */
typedef signed char  const sc8;   /* Read Only */

typedef volatile signed long  vs32;
typedef volatile signed short vs16;
typedef volatile signed char  vs8;

typedef volatile signed long  const vsc32;  /* Read Only */
typedef volatile signed short const vsc16;  /* Read Only */
typedef volatile signed char  const vsc8;   /* Read Only */

typedef unsigned long  u32;
typedef unsigned short u16;
typedef unsigned char  u8;

typedef unsigned long  const uc32;  /* Read Only */
typedef unsigned short const uc16;  /* Read Only */
typedef unsigned char  const uc8;   /* Read Only */

typedef volatile unsigned long  vu32;
typedef volatile unsigned short vu16;
typedef volatile unsigned char  vu8;

typedef volatile unsigned long  const vuc32;  /* Read Only */
typedef volatile unsigned short const vuc16;  /* Read Only */
typedef volatile unsigned char  const vuc8;   /* Read Only */

typedef enum
{
  FALSE = 0,
  TRUE = !FALSE
}
BoolT;

typedef enum {
   RESET = 0,
   SET = !RESET
}
FlagStatus, ITStatus;

typedef enum {
  DISABLE = 0,
  ENABLE = !DISABLE
}
FunctionalState;

#define IS_FUNCTIONALSTATE_OK(VALUE) ( (VALUE == ENABLE) || (VALUE == DISABLE) )

typedef enum {
  ERROR = 0,
  SUCCESS = !ERROR
}
ErrorStatus;

#define U8_MAX     ((u8)255)
#define S8_MAX     ((s8)127)
#define S8_MIN     ((s8)-128)
#define U16_MAX    ((u16)65535u)
#define S16_MAX    ((s16)32767)
#define S16_MIN    ((s16)-32768)
#define U32_MAX    ((u32)4294967295uL)
#define S32_MAX    ((s32)2147483647)
#define S32_MIN    ((s32)2147483648uL)

//LCD pinout
#define LCD_A 0x04
#define LCD_B 0x08
#define LCD_C 0x20
#define LCD_D 0x40
#define LCD_E 0x80
#define LCD_F 0x02
#define LCD_G 0x01
#define LCD_P 0x10

//7segment decoding table - pinout should be done accordingly to LCD_x
#define LCD_CHAR_0 (LCD_A + LCD_B + LCD_C + LCD_D + LCD_E + LCD_F        )
#define LCD_CHAR_1 (        LCD_B + LCD_C                                )
#define LCD_CHAR_2 (LCD_A + LCD_B         + LCD_D + LCD_E         + LCD_G)
#define LCD_CHAR_3 (LCD_A + LCD_B + LCD_C + LCD_D                 + LCD_G)
#define LCD_CHAR_4 (        LCD_B + LCD_C                 + LCD_F + LCD_G)
#define LCD_CHAR_5 (LCD_A         + LCD_C + LCD_D         + LCD_F + LCD_G)
#define LCD_CHAR_6 (LCD_A         + LCD_C + LCD_D + LCD_E + LCD_F + LCD_G)
#define LCD_CHAR_7 (LCD_A + LCD_B + LCD_C                                )
#define LCD_CHAR_8 (LCD_A + LCD_B + LCD_C + LCD_D + LCD_E + LCD_F + LCD_G)
#define LCD_CHAR_9 (LCD_A + LCD_B + LCD_C + LCD_D         + LCD_F + LCD_G)
#define LCD_CHAR_A (LCD_A + LCD_B + LCD_C + LCD_D + LCD_E + LCD_F + LCD_G  + LCD_P)
//LCD_CHAR_A is used for testing purpose

extern unsigned char const LCD_VALUE[];

extern volatile unsigned char LCD_INDEX[3];

extern volatile unsigned char EEPROM_DATA[] @0x9800;

/* Exported constants --------------------------------------------------------*/
/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */

#endif /* __STM8_TYPE_H */

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/
