/** @file   main.c
  * Description : This file provides the main function.
  * @author  MCD VPo
  * @version 1.0
  * @date   02/18/2009
  **/

/******************** (C) COPYRIGHT 2007 STMicroelectronics *******************
*
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMicroelectronics SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*
*******************************************************************************/
/* Includes ------------------------------------------------------------------*/
#include "stdlib.h"
#include "stm8_type.h"
#include "stm8l101.h"
#include "stm8_macro.h"
#include "main.h"

unsigned char const LCD_VALUE[] = {LCD_CHAR_0, LCD_CHAR_1,

																   LCD_CHAR_2, LCD_CHAR_3,
																	 LCD_CHAR_4, LCD_CHAR_5,
																	 LCD_CHAR_6, LCD_CHAR_7,
																	 LCD_CHAR_8, LCD_CHAR_9,
																	 LCD_CHAR_A};
unsigned char LCD_INDEX[3] = {1,0,1};
u8 Flags = 0x00;

void main(void)
{	u8 temp;
		
//port initialization
	PA_DDR = 0x3F;	//output except button
  PA_CR1 = 0x7F;  //push-pull / pull-up

  PB_DDR = 0xFF;	//output
  PB_CR1 = 0xFF;	//push-pull
	
  PC_DDR = 0xFB;	//output except button
  PC_CR1 = 0xFF;	//push-pull / pull-up

  PD_DDR = 0xFF;	//output
  PD_CR1 = 0xFF;	//push-pull

  PA_CR2 = 0x40;  //enable interrupt for button PA6
	PC_CR2 = 0x04;  //enable interrupt for button PC2
  EXTI_CR1 = 0x20;
  EXTI_CR2 = 0x20;

  CLK_CKDIVR = 0x00; //HSI as clock source, no divider
	CLK_PCKENR = 0x40; // enable clock for AWU registers

  // AWU set to refresh rate around 36Hz
  AWU_APR = 30;
  AWU_TBR = 0x07;
  AWU_CSR = 0x10; //AutoWakeup enable

  CLK_PCKENR |= 0x01; //set PCKEN0 - TIM2
	TIM2_PSCR = 0x07; //set Ftim = Fhsi / 8 / 2^PSCR
	TIM2_ARRH = 0x01; //set autoreload value
	TIM2_ARRL = 0x00; //set autoreload value
  TIM2_CR1 = 0x10; //downcounting mode selected
	TIM2_IER = 0x01; //enable timer update interrupt/event
	
	WFE_CR1 = 0x01; //configure TIM2 Update as wfe capable

  CFG_GCR = 0x03; //enable AL bit, disable SWIM
	
  _fctcpy('r');

  if (!(PA_IDR & 0x40)) //if button is pressed, than show all segments for test purpose
  { LCD_INDEX[0] = LCD_INDEX[1] = 0x0A;
	  LCD_INDEX[2] = 9;
	}

/* Folowing routine has to be used if LCD decoding is not transparent.
It means, if there is one 7segment per port, simple 
Px_ODR = LCD_VALUE[LCD_INDEX[x]]; could be used.
LCD_VALUE[] is defined as an interconnection table between ports and segments */

  { u8 S1,S2,S3; // Temporary registers for LCD decoding
	  S1 = LCD_VALUE[LCD_INDEX[2]];
		S2 = LCD_VALUE[LCD_INDEX[1]];
		S3 = LCD_VALUE[LCD_INDEX[0]]; 
		
		//special decoding is needed thanks to layout of PCB... segments has been swapped.
    PA_ODR = ((S3 & 0xF0) >> 2);
		PB_ODR = (S2 & 0x0F) + ((S1 & 0x0F) << 4);
    PC_ODR = ((S2 & 0xF0) >> 1); 
    PD_ODR = (S3 & 0x0F) + ((S1 & 0xE0) >> 1);
	}
		
	rim();
	
  do
	{ 
	  halt();
		{ temp = 2;
  		
			if (Flags & 0x04)
  	  { u8 AR_Delay = AR_DELAY;
				u8 AR_Accel = AR_ACCEL;
			  u8 AR_Count = AR_SPEED;
				u8 AR_Speed = AR_SPEED;
				
			  AWU_CSR = 0x00; //AutoWakeup disable
			  TIM2_CR1 = 0x11; //counter enable
			  do
			  { PB_ODR = ~PB_ODR;
          PC_ODR ^= 0x78;
	        PA_ODR ^= 0x3C;
    	    PD_ODR = ~PD_ODR;
					
					CLK_CKDIVR = 0x03; //HSI as clock source, max divider
					TIM2_SR1 &= 0xFE;

          if (PC_IDR & 0x04)
	  		    temp--;

          PC_CR1 &= ~0x04; //disable pull-up

    			_asm("wfe");
          CLK_CKDIVR = 0x00; //HSI as clock source, max divider
					if (AR_Delay)
					  AR_Delay--;
					else
					  AR_Count--;
						
					if (AR_Count == 0)
					{ AR_Accel--;
					  if (AR_Accel == 0)
						{ AR_Accel = AR_ACCEL;
						  if (AR_Speed > 1) AR_Speed--;
						}
					  AR_Count = AR_Speed;
					  
					  LCD_INDEX[2]++;
						if (LCD_INDEX[2] > 9)
						{ LCD_INDEX[2] = 0;
							LCD_INDEX[1]++;
							if (LCD_INDEX[1] > 9)
							{ LCD_INDEX[1] = 0;
							LCD_INDEX[0]++;
							if (LCD_INDEX[0] > 9)
							  LCD_INDEX[0] = 0; 
							}
						}
						{ u8 S1,S2,S3; // Temporary registers for LCD decoding
  						S1 = LCD_VALUE[LCD_INDEX[2]];
							S2 = LCD_VALUE[LCD_INDEX[1]];
							S3 = LCD_VALUE[LCD_INDEX[0]]; 
		
		          //special decoding is needed thanks to layout of PCB... 
		          // segments has been swapped - see schematics
							PA_ODR = ((S3 & 0xF0) >> 2);
							PB_ODR = (S2 & 0x0F) + ((S1 & 0x0F) << 4);
							PC_ODR = ((S2 & 0xF0) >> 1); 
							PD_ODR = (S3 & 0x0F) + ((S1 & 0xE0) >> 1);
          	}
						
					}
					  
										
					
					PC_CR1 |= 0x04; //enable pull-up
		  	} while(temp);
      
			AWU_CSR = 0x10; //AutoWakeup enable	
			TIM2_CR1 = 0x10;
    	PC_CR2 = 0x04;  //enable interrupt for button PC2
      CFG_GCR = 0x03; //enable AL bit, disable SWIM		
			Flags &= ~0x04;
			}			
 		}
	}
	while (1);
}




