/*	BASIC INTERRUPT VECTOR TABLE FOR STM8 devices
 *	Copyright (c) 2007 STMicroelectronics
 */
#include "stm8l101.h"
#include "stm8_type.h"
#include "RAM_code.h"
#include "main.h"


typedef void @far (*interrupt_handler_t)(void);
//@far @interrupt void AWU_Interrupt (void) @0x9000;


struct interrupt_vector {
	unsigned char interrupt_instruction;
	interrupt_handler_t interrupt_handler;
};


#pragma section (aligned)
/* This function refresh LCD every XXms (defined in AWU Init */
@far @interrupt void AWU_Interrupt (void) 
{ AWU_CSR;

  PB_ODR = ~PB_ODR;
// as long, as I2C is not used, it is less consuming to invert full port
// thanks to faster execution time
	PC_ODR = ~PC_ODR; //  PC_ODR ^= 0x78;
	PA_ODR = ~PA_ODR; //  PA_ODR ^= 0x3C;
  PD_ODR = ~PD_ODR;

	return;
} 
#pragma section (text)


@far @interrupt void Button1_Interrupt (void)
{ 
//  PA_CR1 &= ~0x40; //disable pull-up
	
  CLK_CKDIVR = 0x03; //HSI as clock source, max divider

  Left_Button_RAM();

  CLK_CKDIVR = 0x00; //HSI as clock source, no divider

  EXTI_SR1 &= 0x40; //clear interrupt flag 
	return;
}

@far @interrupt void Button2_Interrupt (void)
{ u8 c;
  PC_CR1 &= ~0x04; //disable pull-up
	PC_CR2 = 0x00;  //disable interrupt for button PC2
	
	Flags |= 0x04;
	
//  CLK_CKDIVR = 0x03; //HSI as clock source, max divider
	//in order to decrease consumption - wait loop expected

  LCD_INDEX[2]++;
	if (LCD_INDEX[2] > 9)
	{
		LCD_INDEX[2] = 0;
  	LCD_INDEX[1]++;
	  if (LCD_INDEX[1] > 9)
		{
			LCD_INDEX[1] = 0;
			LCD_INDEX[0]++;
			if (LCD_INDEX[0] > 9)
			{
				LCD_INDEX[0] = 0;
			}
		}
	}

  { u8 S1,S2,S3; // Temporary registers for LCD decoding
		
	  S1 = LCD_VALUE[LCD_INDEX[2]];
		S2 = LCD_VALUE[LCD_INDEX[1]];
		S3 = LCD_VALUE[LCD_INDEX[0]]; 
		
		//special decoding is needed thanks to layout of PCB... 
		// segments has been swapped - see schematics
    PA_ODR = ((S3 & 0xF0) >> 2);
		PB_ODR = (S2 & 0x0F) + ((S1 & 0x0F) << 4);
    PC_ODR = ((S2 & 0xF0) >> 1); 
    PD_ODR = (S3 & 0x0F) + ((S1 & 0xE0) >> 1);
	}

/*  //this could be used for "transparent" segments mapping
      PB_ODR = LCD_VALUE[LCD_INDEX[2]];
      PC_ODR = LCD_VALUE[LCD_INDEX[1]];
      PD_ODR = LCD_VALUE[LCD_INDEX[0]] | LCD_P;
*/

//  while (!(PC_IDR & 0x04))
  CFG_GCR = 0x01; //disable AL bit, disable SWIM
  PC_CR1 |= 0x04; //enable pull-up

  EXTI_SR1 &= 0x04; //clear interrupt flag 
	return;
}


@far @interrupt void NonHandledInterrupt2 (void)
{
	/* in order to detect unexpected events during development, 
	   it is recommended to set a breakpoint on the following instruction
	*/
	return;
}

@far @interrupt void NonHandledInterrupt (void)
{
	/* in order to detect unexpected events during development, 
	   it is recommended to set a breakpoint on the following instruction
	*/
	return;
}

extern void _stext();     /* startup routine */

struct interrupt_vector const _vectab[] = {
	{0x82, (interrupt_handler_t)_stext}, /* reset */
	{0x82, NonHandledInterrupt}, /* trap  */
	{0x82, NonHandledInterrupt}, /* irq0  */
	{0x82, NonHandledInterrupt}, /* irq1  */
	{0x82, NonHandledInterrupt}, /* irq2  */
	{0x82, NonHandledInterrupt}, /* irq3  */
	{0x82, AWU_Interrupt}, /* irq4  */
	{0x82, NonHandledInterrupt}, /* irq5  */
	{0x82, NonHandledInterrupt}, /* irq6  */
	{0x82, NonHandledInterrupt}, /* irq7  */
	{0x82, NonHandledInterrupt}, /* irq8  */
	{0x82, NonHandledInterrupt}, /* irq9  */
	{0x82, Button2_Interrupt}, /* irq10 */
	{0x82, NonHandledInterrupt}, /* irq11 */
	{0x82, NonHandledInterrupt}, /* irq12 */
	{0x82, NonHandledInterrupt}, /* irq13 */
	{0x82, Button1_Interrupt}, /* irq14 */
	{0x82, NonHandledInterrupt}, /* irq15 */
	{0x82, NonHandledInterrupt}, /* irq16 */
	{0x82, NonHandledInterrupt}, /* irq17 */
	{0x82, NonHandledInterrupt}, /* irq18 */
	{0x82, NonHandledInterrupt}, /* irq19 */
	{0x82, NonHandledInterrupt}, /* irq20 */
	{0x82, NonHandledInterrupt}, /* irq21 */
	{0x82, NonHandledInterrupt}, /* irq22 */
	{0x82, NonHandledInterrupt}, /* irq23 */
	{0x82, NonHandledInterrupt}, /* irq24 */
	{0x82, NonHandledInterrupt}, /* irq25 */
	{0x82, NonHandledInterrupt}, /* irq26 */
	{0x82, NonHandledInterrupt}, /* irq27 */
	{0x82, NonHandledInterrupt}, /* irq28 */
	{0x82, NonHandledInterrupt}, /* irq29 */
};
